@@ -324,6 +324,22 @@ class Client(object):
         """Send a message to a user or channel."""
         self.send("PRIVMSG", target, ":" + message)
 
+    def reply(self, incoming, user, message):
+        """Replies to a user in a given channel or PM.
+
+        If the specified incoming is a user, simply sends a PM to user.
+        If the specified incoming is a channel, prefixes the message with the
+        user's nick and sends it to the channel.
+
+        This is specifically useful in creating responses to commands that can
+        be used in either a channel or in a PM, and responding to the person
+        who invoked the command.
+        """
+        if isinstance(incoming, User):
+            self.msg(user, message)
+        else:
+            self.msg(incoming, "%s: %s" % (user.nick, message))
+
     def notice(self, target, message):
         """Send a NOTICE to a user or channel."""
         self.send("NOTICE", target, ":" + message)
@@ -347,15 +363,16 @@ class Client(object):
             # "JOIN 0" command which actually removes you from all channels
             _log.warning("Refusing to join channel that does not start "
                          "with one of '%s': %s", chantypes, target)
-            return
+            return False
 
         if target in self.server.channels:
             _log.warning("Ignoring request to join channel '%s' because we "
                          "are already in that channel.", target)
-            return
+            return False
 
         _log.info("Joining channel %s ...", target)
         self.send("JOIN", target, *([key] if key else []))
+        return True
 
     def invite(self, channel, nick):
         """Attempt to invite a user to a channel."""
@@ -367,7 +384,9 @@ class Client(object):
             _log.warning("Ignoring request to part channel '%s' because we "
                          "are not in that channel.", target)
             return
+            return False
         self.send("PART", target, *([message] if message else []))
+        return True
 
     def quit(self, message=None):
         """Quit the server (and stop the event loop).
@@ -625,7 +644,8 @@ def _parse_part(client, command, actor, args):
     if actor.nick == client.user.nick:
         client.server.remove_channel(channel)
     client.dispatch_event("PART", actor, channel, message)
-    client.dispatch_event("MEMBERS", channel)
+    if actor.nick != client.user.nick:
+        client.dispatch_event("MEMBERS", channel)
 
 
 @parser("QUIT")
